@@ -29,8 +29,9 @@ class dpd:
         d['fpd30p_amt'] = (x[self.col_fpd30p_amt].sum()/x[self.col_user_principal].sum())*100 
         d['fpd0p_user'] = (x[self.col_is_fpd0].sum()/x[self.col_user_cnt].count())*100
         d['fpd7p_user'] = (x[self.col_is_fpd7].sum()/x[self.col_user_cnt].count())*100
+        d['fpd15p_user'] = (x[self.col_is_fpd15].sum()/x[self.col_user_cnt].count())*100
         d['fpd30p_user'] = (x[self.col_is_fpd30].sum()/x[self.col_user_cnt].count())*100
         d['user_cnt'] = x[self.col_user_cnt].count()
-        return pd.Series(d, index=['fpd0p_amt', 'fpd7p_amt','fpd15p_amt','fpd30p_amt','fpd0p_user','fpd7p_user','fpd30p_user','user_cnt'])
+        return pd.Series(d, index=['fpd0p_amt', 'fpd7p_amt','fpd15p_amt','fpd30p_amt','fpd0p_user','fpd7p_user','fpd15p_user','fpd30p_user','user_cnt'])
 
 
